// @generated by protoc-gen-connect-es v0.8.4 with parameter "target=ts"
// @generated from file greeter.proto (package greeter.v1, syntax proto3)
/* eslint-disable */
// @ts-nocheck

import { HelloRequest, HelloResponse } from "./greeter_pb.js";
import { MethodKind } from "@bufbuild/protobuf";

/**
 * @generated from service greeter.v1.Greeter
 */
export const Greeter = {
  typeName: "greeter.v1.Greeter",
  methods: {
    /**
     * @generated from rpc greeter.v1.Greeter.Hello
     */
    hello: {
      name: "Hello",
      I: HelloRequest,
      O: HelloResponse,
      kind: MethodKind.Unary,
    },
  }
} as const;

